@@ -15,12 +15,7 @@ import numpy as np
 
 from pandas._libs import missing as libmissing
 from pandas._libs.hashtable import object_hash
-from pandas._typing import (
-    DtypeObj,
-    Shape,
-    npt,
-    type_t,
-)
+from pandas._libs.properties import cache_readonly
 from pandas.errors import AbstractMethodError
 
 from pandas.core.dtypes.generic import (
@@ -30,6 +25,15 @@ from pandas.core.dtypes.generic import (
 )
 
 if TYPE_CHECKING:
+    from pandas._typing import (
+        DtypeObj,
+        Self,
+        Shape,
+        npt,
+        type_t,
+    )
+
+    from pandas import Index
     from pandas.core.arrays import ExtensionArray
 
     # To parameterize on same ExtensionDtype
@@ -80,17 +84,22 @@ class ExtensionDtype:
     ``__eq__`` or ``__hash__``, the default implementations here will not
     work.
 
+    Examples
+    --------
+
     For interaction with Apache Arrow (pyarrow), a ``__from_arrow__`` method
     can be implemented: this method receives a pyarrow Array or ChunkedArray
     as only argument and is expected to return the appropriate pandas
-    ExtensionArray for this dtype and the passed values::
+    ExtensionArray for this dtype and the passed values:
 
-        class ExtensionDtype:
-
-            def __from_arrow__(
-                self, array: Union[pyarrow.Array, pyarrow.ChunkedArray]
-            ) -> ExtensionArray:
-                ...
+    >>> import pyarrow
+    >>> from pandas.api.extensions import ExtensionArray
+    >>> class ExtensionDtype:
+    ...     def __from_arrow__(
+    ...         self,
+    ...         array: pyarrow.Array | pyarrow.ChunkedArray
+    ...     ) -> ExtensionArray:
+    ...         ...
 
     This class does not inherit from 'abc.ABCMeta' for performance reasons.
     Methods and properties required by the interface raise
@@ -103,7 +112,7 @@ class ExtensionDtype:
     def __str__(self) -> str:
         return self.name
 
-    def __eq__(self, other: Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         """
         Check whether 'other' is equal to self.
 
@@ -137,7 +146,7 @@ class ExtensionDtype:
         # we need to avoid that and thus use hash function with old behavior
         return object_hash(tuple(getattr(self, attr) for attr in self._metadata))
 
-    def __ne__(self, other: Any) -> bool:
+    def __ne__(self, other: object) -> bool:
         return not self.__eq__(other)
 
     @property
@@ -209,7 +218,7 @@ class ExtensionDtype:
         """
         raise AbstractMethodError(cls)
 
-    def empty(self, shape: Shape) -> type_t[ExtensionArray]:
+    def empty(self, shape: Shape) -> ExtensionArray:
         """
         Construct an ExtensionArray of this dtype with the given shape.
 
@@ -227,15 +236,13 @@ class ExtensionDtype:
         return cls._empty(shape, dtype=self)
 
     @classmethod
-    def construct_from_string(
-        cls: type_t[ExtensionDtypeT], string: str
-    ) -> ExtensionDtypeT:
+    def construct_from_string(cls, string: str) -> Self:
         r"""
         Construct this type from a string.
 
         This is useful mainly for data types that accept parameters.
         For example, a period dtype accepts a frequency parameter that
-        can be set as ``period[H]`` (where H means hourly frequency).
+        can be set as ``period[h]`` (where H means hourly frequency).
 
         By default, in the abstract class, just the name of the type is
         expected. But subclasses can overwrite this method to accept
@@ -261,6 +268,7 @@ class ExtensionDtype:
         For extension dtypes with arguments the following may be an
         adequate implementation.
 
+        >>> import re
         >>> @classmethod
         ... def construct_from_string(cls, string):
         ...     pattern = re.compile(r"^my_type\[(?P<arg_name>.+)\]$")
@@ -390,6 +398,53 @@ class ExtensionDtype:
         """
         return True
 
+    @property
+    def _is_immutable(self) -> bool:
+        """
+        Can arrays with this dtype be modified with __setitem__? If not, return
+        True.
+
+        Immutable arrays are expected to raise TypeError on __setitem__ calls.
+        """
+        return False
+
+    @cache_readonly
+    def index_class(self) -> type_t[Index]:
+        """
+        The Index subclass to return from Index.__new__ when this dtype is
+        encountered.
+        """
+        from pandas import Index
+
+        return Index
+
+    @property
+    def _supports_2d(self) -> bool:
+        """
+        Do ExtensionArrays with this dtype support 2D arrays?
+
+        Historically ExtensionArrays were limited to 1D. By returning True here,
+        authors can indicate that their arrays support 2D instances. This can
+        improve performance in some cases, particularly operations with `axis=1`.
+
+        Arrays that support 2D values should:
+
+            - implement Array.reshape
+            - subclass the Dim2CompatTests in tests.extension.base
+            - _concat_same_type should support `axis` keyword
+            - _reduce and reductions should support `axis` keyword
+        """
+        return False
+
+    @property
+    def _can_fast_transpose(self) -> bool:
+        """
+        Is transposing an array with this dtype zero-copy?
+
+        Only relevant for cases where _supports_2d is True.
+        """
+        return False
+
 
 class StorageExtensionDtype(ExtensionDtype):
     """ExtensionDtype that may be backed by more than one implementation."""
@@ -397,7 +452,7 @@ class StorageExtensionDtype(ExtensionDtype):
     name: str
     _metadata = ("storage",)
 
-    def __init__(self, storage=None) -> None:
+    def __init__(self, storage: str | None = None) -> None:
         self.storage = storage
 
     def __repr__(self) -> str:
@@ -406,7 +461,7 @@ class StorageExtensionDtype(ExtensionDtype):
     def __str__(self) -> str:
         return self.name
 
-    def __eq__(self, other: Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if isinstance(other, str) and other == self.name:
             return True
         return super().__eq__(other)
